@@ -10,9 +10,10 @@ from pathlib import Path
 from azure.storage.blob import BlobServiceClient, BlobClient, ContainerClient, __version__
 
 class DatasetManager: 
-    def __init__(self, localDataRootDir, connectionString=None):
+    def __init__(self, localDataRootDir, connectionString=None, container=None):
         self.localDataRootDir = localDataRootDir
-        self.connectionString = connectionString   
+        self.connectionString = connectionString
+        self.container = container   
     
     @staticmethod
     def loadDatasetFromFiles(t1_file, t2_file, m0_file,mprage_file, tse_file, 
@@ -66,12 +67,12 @@ class DatasetManager:
                                          path_base+"_mprage.nii", path_base+"_tse.nii", registered_mprage_file, registered_tse_file)
 
     def fetchDatasetFromAzure(self, subject, scanner, set):
-        if(self.connectionString == None):
-            print("Dataset Manager Azure connection string not set.")
+        if(self.connectionString == None or self.container == None):
+            print("Dataset Manager Azure connection string or container not set.")
             return None
         else:
             blob_service_client = BlobServiceClient.from_connection_string(self.connectionString)
-            container_name = "nifti-source"
+            container_name = self.container
             container_client = blob_service_client.get_container_client(container_name)
             uri_base = subject+"/"+scanner+"/"+set
             path_dir = self.localDataRootDir+"/"+subject+"/"+scanner
@@ -100,11 +101,13 @@ class DatasetManager:
         else:
             blob_service_client = BlobServiceClient.from_connection_string(self.connectionString)
             container_name = containerName
-            container_client = blob_service_client.get_container_client(container_name)
+            try:
+                container_client = blob_service_client.get_container_client(container_name)
+            except Exception as e:
+                container_client = blob_service_client.create_container(container_name)
             uri_base = subject+"/"+scanner
             path_dir = self.localDataRootDir+"/"+subject+"/"+scanner
             Path(path_dir).mkdir( parents=True, exist_ok=True )
-            container_client = blob_service_client.get_container_client(container= container_name) 
             files = os.listdir(path_dir)
             filesToUpload = []
             for file in files:
@@ -116,7 +119,7 @@ class DatasetManager:
                 blob_client = blob_service_client.get_blob_client(container=container_name, blob=uri)
                 # Upload the created file
                 with open(filepath, "rb") as data:
-                    blob_client.upload_blob(data)
+                    blob_client.upload_blob(data, overwrite=True)
                     print("Uploaded: " + uri)
                     
      
